.. tephi documentation master file, created by
   sphinx-quickstart on Thu Jun 26 15:24:09 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

The tephi user guide
====================

This user guide gives a brief introduction to the tephigram plotting capability provided by tephi.

.. warning::
   This module is currently in beta release and is liable to change.

User guide table of contents
----------------------------

.. toctree::
   :caption: Getting Started
   :maxdepth: 3
   :numbered:

   introduction.rst
   plotting.rst
   customise.rst
   barbs.rst
   glossary.rst


.. toctree::
   :caption: API
   :maxdepth: 2

   api/modules